EXTERNAL_NUM_INTERRUPTS = 16
NUM_DIGITAL_PINS        = 40
NUM_ANALOG_INPUTS       = 7

TX = 34;
RX = 35;

SDA = 21;
SCL = 22;

SS    = 29;
MOSI  = 37;
MISO  = 31;
SCK   = 30;

A0 = 36;   # BUILTIN_Potentiometer
A1 = 39;   # BUILTIN_CDS
A2 = 32;   # BUILTIN_temperature
A3 = 33;   # Analog Input
A4 = 34;   # Analog Input
A5 = 35;   # Analog Input
A6 = 25;   # Analog Input
A7 = 26;   # Analog Input


D2 = 27;   # BUILTIN_LED_Red
D3 = 14;   # BUILTIN_LED_Blue
D4 = 12;   # BUILTIN_LED_Green
D5 = 13;   # BUILTIN_LED_Yellow
D6 = 15;   # BUILTIN_BUTTON_Red
D7 = 16;   # BUILTIN_BUTTON_Blue
D8 = 17;   # BUILTIN_BUTTON_Green
D9 = 4;    # BUILTIN_BUTTON_Yellow

DAC1 = 25;
DAC2 = 26;

HIGH = 1
LOW = 0